:orphan:

*****************
`Interval` class
*****************


.. autoclass:: timeboard.Interval
   :members: first, last, nth, total_duration, worktime, count, 
             count_periods, what_portion_of, to_dataframe, overlap,
             workshifts, __mul__, __div__
